==> tasks-v1.8.8.zip: tasks/messages/zh-CN/base.php <==
<?php

return [
    'All Day' => '全天',
    'Close' => '关闭',
    'Color' => '颜色',
    'Created by me' => '我创建的',
    'Date' => '日期',
    'Delete' => '删除',
    'Description' => '描述',
    'Edit' => '编辑',
    'End Date' => '结束日期',
    'End time must be after start time!' => '结束时间必须晚于开始时间！',
    'Filter' => '筛选',
    'General' => '一般',
    'General Settings' => '一般设置',
    'Overview' => '概览',
    'Sort order' => '排序',
    'Spaces' => '空间',
    'Start Date' => '开始日期',
    'Status' => '状态',
    'Tasks' => '任务',
    'Title' => '标题',
    'View Online' => '在线看',
    'You have insufficient permissions to perform that operation!' => '您没有足够的权限执行这个操作!',
    '{userName} finished task {task}.' => '{task} 完成任务 {userName} .',
    '1 Day before' => '',
    '1 Month before' => '',
    '1 Week before' => '',
    '2 Days before' => '',
    '2 Weeks before' => '',
    '3 Weeks before' => '',
    '<strong>Assigned users</strong> are allowed to process this task.' => '',
    '<strong>Confirm</strong> task deletion' => '',
    '<strong>Create</strong> task list' => '',
    '<strong>Edit</strong> task' => '',
    '<strong>Edit</strong> task list' => '',
    '<strong>New</strong> Task' => '',
    '<strong>Task</strong> Overview' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    '<strong>Your</strong> tasks' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Accept Task' => '',
    'Add Deadline to space calendar' => '',
    'Add checkpoint...' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Add reminder' => '',
    'Add responsible users' => '',
    'Add schedule to the space calendar' => '',
    'Add task' => '',
    'Add to space calendar' => '',
    'Additional options' => '',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => '',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => '',
    'Allows the user to process unassigned tasks' => '',
    'Already requested' => '',
    'Any user with a "Process unassigned tasks" permission can work on this task' => '',
    'Anyone can work on this task!' => '',
    'Assign myself' => '',
    'Assign users' => '',
    'Assigned' => '',
    'Assigned users' => '',
    'Assignment' => '',
    'Assignments:' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Begin Task' => '',
    'Checklist Items' => '',
    'Checklist:' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Continue Review' => '',
    'Create tasks' => '',
    'Deadline at' => '',
    'Deadline: ' => '',
    'Delete list' => '',
    'Do not remind' => '',
    'Do you really want to delete this task?' => '',
    'Don\'t add to calendar' => '',
    'Drag entry' => '',
    'Edit item (empty field will be removed)...' => '',
    'Edit list' => '',
    'End' => '',
    'End Time' => '',
    'End date' => '',
    'Extend deadline request' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'Filter tasks' => '',
    'Finish Task' => '',
    'Hide this list once all tasks are completed' => '',
    'I\'m assigned' => '',
    'I\'m responsible' => '',
    'If empty any user can complete the task.' => '',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => '',
    'In Progress' => '',
    'In Review' => '',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => '',
    'Invalid task list selection.' => '',
    'Let Task Review' => '',
    'Main Navigation' => '',
    'Manage tasks' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No Scheduling set for this Task' => '',
    'No pending tasks found' => '',
    'No results found for the given filter.' => '',
    'Open Task' => '',
    'Other Tasks' => '',
    'Overdue' => '',
    'Parent Task' => '',
    'Pending' => '',
    'Pending Review' => '',
    'Process unassigned tasks' => '',
    'Ready For Review' => '',
    'Receive Notifications for Task Reminder.' => '',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => '',
    'Reject Task' => '',
    'Remind Mode' => '',
    'Reminder' => '',
    'Reminder sent' => '',
    'Reminders' => '',
    'Request extension' => '',
    'Request sent' => '',
    'Reset Task' => '',
    'Responsible' => '',
    'Responsible users' => '',
    'Review by responsible user required' => '',
    'Scheduling' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => '',
    'Sort Order' => '',
    'Start' => '',
    'Start Time' => '',
    'Start date' => '',
    'Starting at' => '',
    'Task' => '',
    'Task List' => '',
    'Task Users have been notified' => '',
    'Task content ID' => '',
    'Task {task} in space {spaceName} ends at {dateTime}.' => '',
    'Task {task} in space {spaceName} starts at {dateTime}.' => '',
    'Tasks: Reminder' => '',
    'This task can only be processed by assigned and responsible users.' => '',
    'This task requires to be reviewed by a responsible' => '',
    'Time Zone' => '',
    'Title and Color' => '',
    'Title of your task list' => '',
    'Today' => '',
    'Unsorted' => '',
    'You are assigned!' => '',
    'You are responsible!' => '',
    'Your Reminder for task {task}' => '',
    'ending Review' => '',
    'view all' => '',
    '{count,plural,=1{# day} other{# days}} remaining' => '',
    '{displayName} is assigned to this task' => '',
    '{displayName} is responsible for this task' => '',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '',
    '{userName} assigned you to task {task} in space {spaceName}.' => '',
    '{userName} completed Task {task} in space {spaceName}.' => '',
    '{userName} completed task {task}.' => '',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '',
    '{userName} has re-opened task {task} in space {spaceName}.' => '',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '',
    '{userName} reset task {task}.' => '',
    '{userName} reviewed task {task}.' => '',
    '{userName} started working on Task {task} in space {spaceName}.' => '',
    '{userName} works on task {task}.' => '',
];

==> tasks-v1.9.2.zip: tasks/messages/zh-CN/base.php <==
<?php

return [
    'All Day' => '全天',
    'Close' => '关闭',
    'Color' => '颜色',
    'Created by me' => '我创建的',
    'Date' => '日期',
    'Delete' => '删除',
    'Description' => '描述',
    'Edit' => '编辑',
    'End Date' => '结束日期',
    'End time must be after start time!' => '结束时间必须晚于开始时间！',
    'Filter' => '筛选',
    'General' => '一般',
    'General Settings' => '一般设置',
    'Overview' => '概览',
    'Sort order' => '排序',
    'Spaces' => '空间',
    'Start Date' => '开始日期',
    'Status' => '状态',
    'Tasks' => '任务',
    'Title' => '标题',
    'View Online' => '在线看',
    'You have insufficient permissions to perform that operation!' => '您没有足够的权限执行这个操作!',
    '{userName} finished task {task}.' => '{task} 完成任务 {userName} .',
    '1 Day before' => '',
    '1 Month before' => '',
    '1 Week before' => '',
    '2 Days before' => '',
    '2 Weeks before' => '',
    '3 Weeks before' => '',
    '<strong>Assigned users</strong> are allowed to process this task.' => '',
    '<strong>Confirm</strong> task deletion' => '',
    '<strong>Create</strong> task list' => '',
    '<strong>Edit</strong> task' => '',
    '<strong>Edit</strong> task list' => '',
    '<strong>New</strong> Task' => '',
    '<strong>Task</strong> Overview' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    '<strong>Your</strong> tasks' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Accept Task' => '',
    'Add Deadline to space calendar' => '',
    'Add checkpoint...' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Add reminder' => '',
    'Add responsible users' => '',
    'Add schedule to the space calendar' => '',
    'Add task' => '',
    'Add to space calendar' => '',
    'Additional options' => '',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => '',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => '',
    'Allows the user to process unassigned tasks' => '',
    'Already requested' => '',
    'Assign myself' => '',
    'Assign users' => '',
    'Assigned users' => '',
    'Assignment' => '',
    'Assignments' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Begin Task' => '',
    'Checklist Items' => '',
    'Checklist:' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Continue Review' => '',
    'Create tasks' => '',
    'Deadline' => '',
    'Deadline: ' => '',
    'Delete list' => '',
    'Do not remind' => '',
    'Do you really want to delete this task?' => '',
    'Don\'t add to calendar' => '',
    'Edit item (empty field will be removed)...' => '',
    'Edit list' => '',
    'End' => '',
    'End Time' => '',
    'End date' => '',
    'Extend deadline request' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'Filter tasks' => '',
    'Finish Task' => '',
    'Hide this list once all tasks are completed' => '',
    'I\'m assigned' => '',
    'I\'m responsible' => '',
    'ID' => '',
    'If empty any user can complete the task.' => '',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => '',
    'In Progress' => '',
    'In Review' => '',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => '',
    'Invalid task list selection.' => '',
    'Let Task Review' => '',
    'Main Navigation' => '',
    'Manage tasks' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No Scheduling set for this Task' => '',
    'No pending tasks found' => '',
    'No results found for the given filter.' => '',
    'Open Task' => '',
    'Other Tasks' => '',
    'Overdue' => '',
    'Parent Task' => '',
    'Pending' => '',
    'Pending Review' => '',
    'Process unassigned tasks' => '',
    'Ready For Review' => '',
    'Receive Notifications for Task Reminder.' => '',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => '',
    'Reject Task' => '',
    'Remind Mode' => '',
    'Reminder' => '',
    'Reminder sent' => '',
    'Reminders' => '',
    'Request Review' => '',
    'Request extension' => '',
    'Request sent' => '',
    'Reset Task' => '',
    'Responsible' => '',
    'Responsible users' => '',
    'Review by responsible user required' => '',
    'Scheduling' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => '',
    'Sort Order' => '',
    'Start' => '',
    'Start Time' => '',
    'Start date' => '',
    'Starting at' => '',
    'Task' => '',
    'Task List' => '',
    'Task Users have been notified' => '',
    'Task content ID' => '',
    'Task {task} in space {spaceName} ends at {dateTime}.' => '',
    'Task {task} in space {spaceName} starts at {dateTime}.' => '',
    'Tasks: Reminder' => '',
    'This task requires to be reviewed by a responsible' => '',
    'Time Zone' => '',
    'Title and Color' => '',
    'Title of your task list' => '',
    'Today' => '',
    'Unsorted' => '',
    'Your Reminder for task {task}' => '',
    'view all' => '',
    '{count,plural,=1{# day} other{# days}} remaining' => '',
    '{displayName} is assigned to this task' => '',
    '{displayName} is responsible for this task' => '',
    '{displayName} is task creator' => '',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '',
    '{userName} assigned you to task {task} in space {spaceName}.' => '',
    '{userName} completed Task {task} in space {spaceName}.' => '',
    '{userName} completed task {task}.' => '',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '',
    '{userName} has re-opened task {task} in space {spaceName}.' => '',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '',
    '{userName} reset task {task}.' => '',
    '{userName} reviewed task {task}.' => '',
    '{userName} started working on Task {task} in space {spaceName}.' => '',
    '{userName} works on task {task}.' => '',
];
